@@ -3,9 +3,7 @@ pub use super::*;
 pub type TokenType = u16;
 
 pub const ID_TOKEN: TokenType = 10 << 1;
-pub const CHAR_TOKEN: TokenType = 20 << 2;
-pub const HEX_TOKEN: TokenType = 30 << 3;
-pub const INT_TOKEN: TokenType = 40 << 4;
+pub const INT_TOKEN: TokenType = 20 << 2;
 
 #[derive(Clone, Debug, PartialEq)]
 pub struct Token {
